# Optiflow
<img src="Images/optiflow_logo.png" alt="drawing" width="500"/>

**optiflow** is an algorithm design to reconstruct **velocity fields** from **kymographs** with **optimal transport**. Indeed, optimal transport gives the velocity field of minimal work, which is relevant under a wide array of situations and does not necessitates hard physical assumptions, except for the conservation of the physical quantity that we are measuring across time.
This software is designed to offer cell biologists a simple method to obtain these flow fields, that are notably hard to measure.


---
## Example
<img src="Images/optiflow_example.png" alt="drawing" width="500"/>
An example is provided in the jupyter notebook Optiflow_presentation.ipynb
---

---
## Installation
To install the package 

`python -m pip install`
---

**optiflow** was created by Sacha Ichbiah during his PhD in [Turlier Lab](https://www.turlierlab.com), during a collaboration with Henry de Belly, with the lab of [Orion Weiner](https://weinerlab.com), and is maintained by Sacha Ichbiah and Hervé Turlier. For support, please open an issue.
A preprint of the paper using this method will be published soon. If you use our library in your work please cite the paper.


